Nion Swift Experimental
=======================

A Nion Swift package for experimental menu items and scripts and other items.

This is a public repository maintained primarily by Nion.

.. start-badges

.. list-table::
    :stub-columns: 1

    * - package
      - |version|

.. |version| image:: https://img.shields.io/pypi/v/nionswift-experimental.svg
   :target: https://pypi.org/project/nionswift-experimental/
   :alt: Latest PyPI version

.. end-badges

More Information
----------------

- `Changelog <https://github.com/nion-software/experimental/blob/master/CHANGES.rst>`_
